@@ -71,7 +71,7 @@ public final class Grid
 	 */
 	private final ContainerWrapper container;
 
-	/** An x, y array implemented as a sparse array to accomodate for any grid size without wasting memory (or rather 15 bit (0-MAX_GRID * 0-MAX_GRID).
+	/** An x, y array implemented as a sparse array to accommodate for any grid size without wasting memory (or rather 15 bit (0-MAX_GRID * 0-MAX_GRID).
 	 */
 	private final LinkedHashMap<Integer, Cell> grid = new LinkedHashMap<Integer, Cell>();   // [(y << 16) + x] -> Cell. null key for absolute positioned compwraps
 
@@ -89,10 +89,10 @@ public final class Grid
 	 */
 	private FlowSizeSpec colFlowSpecs = null, rowFlowSpecs = null;
 
-	/** Components that are connectione in one dimension (such as baseline alignment for instance) are grouped together and stored here.
+	/** Components that are connections in one dimension (such as baseline alignment for instance) are grouped together and stored here.
 	 * One for each row/column.
 	 */
-	private ArrayList<LinkedDimGroup>[] colGroupLists, rowGroupLists;   //[(start)row/col number]
+	private final ArrayList<LinkedDimGroup>[] colGroupLists, rowGroupLists;   //[(start)row/col number]
 
 	/** The in the constructor calculated min/pref/max size of the whole grid.
 	 */
@@ -420,9 +420,9 @@ public final class Grid
 
 		// Add synthetic indexes for empty rows and columns so they can get a size
 		for (int i = 0, iSz = rowConstr.getCount(); i < iSz; i++)
-			rowIndexes.add(new Integer(i));
+			rowIndexes.add(Integer.valueOf(i));
 		for (int i = 0, iSz = colConstr.getCount(); i < iSz; i++)
-			colIndexes.add(new Integer(i));
+			colIndexes.add(Integer.valueOf(i));
 
 		colGroupLists = divideIntoLinkedGroups(false);
 		rowGroupLists = divideIntoLinkedGroups(true);
@@ -577,16 +577,21 @@ public final class Grid
 		}
 	}
 
+	public ContainerWrapper getContainer()
+	{
+		return container;
+	}
+
 	public final int[] getWidth()
 	{
 		checkSizeCalcs();
-		return width;
+		return width.clone();
 	}
 
 	public final int[] getHeight()
 	{
 		checkSizeCalcs();
-		return height;
+		return height.clone();
 	}
 
 	private void checkSizeCalcs()
@@ -602,6 +607,9 @@ public final class Grid
 			if (linkTargetIDs == null) {
 				resetLinkValues(false, true);
 			} else {
+				// This call makes some components flicker on SWT. They get their bounds changed twice since
+				// the change might affect the absolute size adjustment below. There's no way around this that
+				// I know of.
 				layout(new int[4], null, null, false, false);
 				resetLinkValues(false, false);
 			}
@@ -611,7 +619,7 @@ public final class Grid
 		}
 	}
 
-	private final UnitValue[] getPos(ComponentWrapper cw, CC cc)
+	private UnitValue[] getPos(ComponentWrapper cw, CC cc)
 	{
 		UnitValue[] cbPos = null;
 		if (callbackList != null) {
@@ -634,7 +642,7 @@ public final class Grid
 		return ccPos;
 	}
 
-	private final BoundSize[] getCallbackSize(ComponentWrapper cw)
+	private BoundSize[] getCallbackSize(ComponentWrapper cw)
 	{
 		if (callbackList != null) {
 			for (int i = 0; i < callbackList.size(); i++) {
@@ -646,7 +654,7 @@ public final class Grid
 		return null;
 	}
 
-	private static final int getDockInsets(TreeSet<Integer> set)
+	private static int getDockInsets(TreeSet<Integer> set)
 	{
 		int c = 0;
 		for (Iterator<Integer> it = set.iterator(); it.hasNext();) {
@@ -699,7 +707,7 @@ public final class Grid
 	 * @param cnt How many cells to advance.
 	 * @return The new value in the "incresing" dimension.
 	 */
-	private final int increase(int[] p, int cnt)
+	private int increase(int[] p, int cnt)
 	{
 		return lc.isFlowX() ? (p[0] += cnt) : (p[1] += cnt);
 	}
@@ -708,7 +716,7 @@ public final class Grid
 	 * @param cellXY The point to wrap and thus set either x or y to 0 and increase the other one.
 	 * @param gapSize The gaps size specified in a "wrap XXX" or "newline XXX" or <code>null</code> if none.
 	 */
-	private final void wrap(int[] cellXY, BoundSize gapSize)
+	private void wrap(int[] cellXY, BoundSize gapSize)
 	{
 		boolean flowx = lc.isFlowX();
 		cellXY[0] = flowx ? 0 : cellXY[0] + 1;
@@ -718,14 +726,14 @@ public final class Grid
 			if (wrapGapMap == null)
 				wrapGapMap = new HashMap<Integer, BoundSize>(8);
 
-			wrapGapMap.put(new Integer(cellXY[flowx ? 1 : 0]), gapSize);
+			wrapGapMap.put(Integer.valueOf(cellXY[flowx ? 1 : 0]), gapSize);
 		}
 
 		// add the row/column so that the gap in the last row/col will not be removed.
 		if (flowx) {
-			rowIndexes.add(new Integer(cellXY[1]));
+			rowIndexes.add(Integer.valueOf(cellXY[1]));
 		} else {
-			colIndexes.add(new Integer(cellXY[0]));
+			colIndexes.add(Integer.valueOf(cellXY[0]));
 		}
 	}
 
@@ -1055,7 +1063,7 @@ public final class Grid
 			putSizesAndIndexes(container.getComponent(), rowColSizes, ixArr, isRows);
 		}
 
-		int curPos = align != null ? Math.round(align.getPixels(refSize - LayoutUtil.sum(rowColSizes), container, null)) : 0;
+		int curPos = align != null ? align.getPixels(refSize - LayoutUtil.sum(rowColSizes), container, null) : 0;
 
 		if (fromEnd)
 			curPos = refSize - curPos;
@@ -1106,13 +1114,13 @@ public final class Grid
 
 			Integer oldEnd = endGroups.get(endGroup);
 			if (oldEnd == null || end > oldEnd.intValue())
-				endGroups.put(endGroup, new Integer(end));
+				endGroups.put(endGroup, Integer.valueOf(end));
 		}
 		return endGroups;
 	}
 
 	/** Calculates Min, Preferred and Max size for the columns OR rows.
-	 * @param isHor If it is the horizontal dimension to caclulate.
+	 * @param isHor If it is the horizontal dimension to calculate.
 	 * @return The sizes in a {@link net.miginfocom.layout.Grid.FlowSizeSpec}.
 	 */
 	private FlowSizeSpec calcRowsOrColsSizes(boolean isHor)
@@ -1126,13 +1134,13 @@ public final class Grid
 			refSize = cSz.constrain(refSize, getParentSize(container, isHor), container);
 
 		DimConstraint[] primDCs = (isHor? colConstr : rowConstr).getConstaints();
-		TreeSet<Integer> primIdexes = isHor ? colIndexes : rowIndexes;
+		TreeSet<Integer> primIndexes = isHor ? colIndexes : rowIndexes;
 
-		int[][] rowColBoundSizes = new int[primIdexes.size()][];
+		int[][] rowColBoundSizes = new int[primIndexes.size()][];
 		HashMap<String, int[]> sizeGroupMap = new HashMap<String, int[]>(2);
-		DimConstraint[] allDCs = new DimConstraint[primIdexes.size()];
+		DimConstraint[] allDCs = new DimConstraint[primIndexes.size()];
 
-		Iterator<Integer> primIt = primIdexes.iterator();
+		Iterator<Integer> primIt = primIndexes.iterator();
 		for (int r = 0; r < rowColBoundSizes.length; r++) {
 			int cellIx = primIt.next().intValue();
 			int[] rowColSizes = new int[3];
@@ -1328,7 +1336,7 @@ public final class Grid
 			if (edgeBefore && edgeAfter)
 				continue;
 
-			BoundSize wrapGapSize = (wrapGapMap == null || isHor == lc.isFlowX() ? null : wrapGapMap.get(new Integer(wgIx++)));
+			BoundSize wrapGapSize = (wrapGapMap == null || isHor == lc.isFlowX() ? null : wrapGapMap.get(Integer.valueOf(wgIx++)));
 
 			if (wrapGapSize == null) {
 
@@ -1386,14 +1394,14 @@ public final class Grid
 	}
 
 	/** Adjust min/pref size for columns(or rows) that has components that spans multiple columns (or rows).
-	 * @param specs The specs for the columns or rows. Last index will be used of <code>count</code> is greater than this array's length.
+	 * @param specs The specs for the columns or rows. Last index will be used if <code>count</code> is greater than this array's length.
 	 * @param defPush The default grow weight if the specs does not have anyone that will grow. Comes from "push" in the CC.
 	 * @param fss
 	 * @param groupsLists
 	 */
 	private void adjustMinPrefForSpanningComps(DimConstraint[] specs, Float[] defPush, FlowSizeSpec fss, ArrayList<LinkedDimGroup>[] groupsLists)
 	{
-		for (int r = 0; r < groupsLists.length; r++) {
+		for (int r = groupsLists.length - 1; r >= 0; r--) { // Since 3.7.3 Iterate from end to start. Will solve some multiple spanning components hard to solve problems.
 			ArrayList<LinkedDimGroup> groups = groupsLists[r];
 
 			for (int i = 0; i < groups.size(); i++) {
@@ -1417,8 +1425,8 @@ public final class Grid
 					}
 
 					if (rowSize < cSize) {
-						for (int eag = 0, newRowSize = 0; eag < 4 && newRowSize < cSize; eag++)
-							newRowSize = fss.expandSizes(specs, defPush, cSize, sIx, len, s, eag);
+						for (int eagerness = 0, newRowSize = 0; eagerness < 4 && newRowSize < cSize; eagerness++)
+							newRowSize = fss.expandSizes(specs, defPush, cSize, sIx, len, s, eagerness);
 					}
 				}
 			}
@@ -1545,7 +1553,7 @@ public final class Grid
 
 	private Cell getCell(int r, int c)
 	{
-		return grid.get(new Integer((r << 16) + c));
+		return grid.get(Integer.valueOf((r << 16) + c));
 	}
 
 	private void setCell(int r, int c, Cell cell)
@@ -1553,10 +1561,10 @@ public final class Grid
 		if (c < 0 || c > MAX_GRID || r < 0 || r > MAX_GRID)
 			throw new IllegalArgumentException("Cell position out of bounds. row: " + r + ", col: " + c);
 
-		rowIndexes.add(new Integer(r));
-		colIndexes.add(new Integer(c));
+		rowIndexes.add(Integer.valueOf(r));
+		colIndexes.add(Integer.valueOf(c));
 
-		grid.put(new Integer((r << 16) + c), cell);
+		grid.put(Integer.valueOf((r << 16) + c), cell);
 	}
 
 	/** Adds a docking cell. That cell is outside the normal cell indexes.
@@ -1573,7 +1581,7 @@ public final class Grid
 				r = side == 0 ? dockInsets[0]++ : dockInsets[2]--;
 				c = dockInsets[1];
 				spanx = dockInsets[3] - dockInsets[1] + 1;  // The +1 is for cell 0.
-				colIndexes.add(new Integer(dockInsets[3])); // Make sure there is a receiving cell
+				colIndexes.add(Integer.valueOf(dockInsets[3])); // Make sure there is a receiving cell
 				break;
 
 			case 1:
@@ -1581,17 +1589,17 @@ public final class Grid
 				c = side == 1 ? dockInsets[1]++ : dockInsets[3]--;
 				r = dockInsets[0];
 				spany = dockInsets[2] - dockInsets[0] + 1;  // The +1 is for cell 0.
-				rowIndexes.add(new Integer(dockInsets[2])); // Make sure there is a receiving cell
+				rowIndexes.add(Integer.valueOf(dockInsets[2])); // Make sure there is a receiving cell
 				break;
 
 			default:
 				throw new IllegalArgumentException("Internal error 123.");
 		}
 
-		rowIndexes.add(new Integer(r));
-		colIndexes.add(new Integer(c));
+		rowIndexes.add(Integer.valueOf(r));
+		colIndexes.add(Integer.valueOf(c));
 
-		grid.put(new Integer((r << 16) + c), new Cell(cw, spanx, spany, spanx > 1));
+		grid.put(Integer.valueOf((r << 16) + c), new Cell(cw, spanx, spany, spanx > 1));
 	}
 
 	/** A simple representation of a cell in the grid. Contains a number of component wraps and if they span more than one cell.
@@ -1755,7 +1763,7 @@ public final class Grid
 			}
 		}
 
-		private final int getSize(BoundSize uvs, int sizeType, boolean isHor, int sizeHint)
+		private int getSize(BoundSize uvs, int sizeType, boolean isHor, int sizeHint)
 		{
 			if (uvs == null || uvs.getSize(sizeType) == null) {
 				switch(sizeType) {
@@ -1772,7 +1780,7 @@ public final class Grid
 			return uvs.getSize(sizeType).getPixels(isHor ? par.getWidth() : par.getHeight(), par, comp);
 		}
 
-		private final void calcGaps(ComponentWrapper before, CC befCC, ComponentWrapper after, CC aftCC, String tag, boolean flowX, boolean isLTR)
+		private void calcGaps(ComponentWrapper before, CC befCC, ComponentWrapper after, CC aftCC, String tag, boolean flowX, boolean isLTR)
 		{
 			ContainerWrapper par = comp.getParent();
 			int parW = par.getWidth();
@@ -1787,7 +1795,7 @@ public final class Grid
 			mergeGapSizes(cc.getHorizontal().getComponentGaps(par, comp, aftGap, (flowX ? after : null), tag, parW, 3, isLTR), true, false);
 		}
 
-		private final void setDimBounds(int start, int size, boolean isHor)
+		private void setDimBounds(int start, int size, boolean isHor)
 		{
 			if (isHor) {
 				x = start;
@@ -1798,7 +1806,7 @@ public final class Grid
 			}
 		}
 
-		private final boolean isPushGap(boolean isHor, boolean isBefore)
+		private boolean isPushGap(boolean isHor, boolean isBefore)
 		{
 			if (isHor && ((isBefore ? 1 : 2) & forcedPushGaps) != 0)
 				return true;    // Forced
@@ -1811,7 +1819,7 @@ public final class Grid
 		/**
 		 * @return If the preferred size have changed because of the new bounds.
 		 */
-		private final boolean transferBounds(boolean checkPrefChange)
+		private boolean transferBounds(boolean checkPrefChange)
 		{
 			comp.setBounds(x, y, w, h);
 
@@ -1825,7 +1833,7 @@ public final class Grid
 			return false;
 		}
 
-		private final void setSizes(int[] sizes, boolean isHor)
+		private void setSizes(int[] sizes, boolean isHor)
 		{
 			if (sizes == null)
 				return;
@@ -1844,7 +1852,7 @@ public final class Grid
 			gaps[ix] = minPrefMax;
 		}
 
-		private final void mergeGapSizes(int[] sizes, boolean isHor, boolean isTL)
+		private void mergeGapSizes(int[] sizes, boolean isHor, boolean isTL)
 		{
 			if (gaps == null)
 				gaps = new int[][] {null, null, null, null};
@@ -1864,46 +1872,46 @@ public final class Grid
 			oldGaps[LayoutUtil.MAX] = Math.min(sizes[LayoutUtil.MAX], oldGaps[LayoutUtil.MAX]);
 		}
 
-		private final int getGapIx(boolean isHor, boolean isTL)
+		private int getGapIx(boolean isHor, boolean isTL)
 		{
 			return isHor ? (isTL ? 1 : 3) : (isTL ? 0 : 2);
 		}
 
-		private final int getSizeInclGaps(int sizeType, boolean isHor)
+		private int getSizeInclGaps(int sizeType, boolean isHor)
 		{
 			return filter(sizeType, getGapBefore(sizeType, isHor) + getSize(sizeType, isHor) + getGapAfter(sizeType, isHor));
 		}
 
-		private final int getSize(int sizeType, boolean isHor)
+		private int getSize(int sizeType, boolean isHor)
 		{
 			return filter(sizeType, isHor ? horSizes[sizeType] : verSizes[sizeType]);
 		}
 
-		private final int getGapBefore(int sizeType, boolean isHor)
+		private int getGapBefore(int sizeType, boolean isHor)
 		{
 			int[] gaps = getGaps(isHor, true);
 			return gaps != null ? filter(sizeType, gaps[sizeType]) : 0;
 		}
 
-		private final int getGapAfter(int sizeType, boolean isHor)
+		private int getGapAfter(int sizeType, boolean isHor)
 		{
 			int[] gaps = getGaps(isHor, false);
 			return gaps != null ? filter(sizeType, gaps[sizeType]) : 0;
 		}
 
-		private final int[] getGaps(boolean isHor, boolean isTL)
+		private int[] getGaps(boolean isHor, boolean isTL)
 		{
 			return gaps[getGapIx(isHor, isTL)];
 		}
 
-		private final int filter(int sizeType, int size)
+		private int filter(int sizeType, int size)
 		{
 			if (size == LayoutUtil.NOT_SET)
 				return sizeType != LayoutUtil.MAX ? 0 : LayoutUtil.INF;
 			return constrainSize(size);
 		}
 
-		private final boolean isBaselineAlign(boolean defValue)
+		private boolean isBaselineAlign(boolean defValue)
 		{
 			Float g = cc.getVertical().getGrow();
 			if (g != null && g.intValue() != 0)
@@ -1913,7 +1921,7 @@ public final class Grid
 			return (al != null ? al == UnitValue.BASELINE_IDENTITY : defValue) && comp.hasBaseline();
 		}
 
-		private final int getBaseline(int sizeType)
+		private int getBaseline(int sizeType)
 		{
 			return comp.getBaseline(getSize(sizeType, true), getSize(sizeType, false));
 		}
@@ -2092,7 +2100,7 @@ public final class Grid
 		return constrainSize(size);
 	}
 
-	private static final int getTotalSizeSerial(ArrayList<CompWrap> compWraps, int sType, boolean isHor)
+	private static int getTotalSizeSerial(ArrayList<CompWrap> compWraps, int sType, boolean isHor)
 	{
 		int totSize = 0;
 		for (int i = 0, iSz = compWraps.size(), lastGapAfter = 0; i < iSz; i++) {
@@ -2110,7 +2118,7 @@ public final class Grid
 		return constrainSize(totSize);
 	}
 
-	private static final int getTotalGroupsSizeParallel(ArrayList<LinkedDimGroup> groups, int sType, boolean countSpanning)
+	private static int getTotalGroupsSizeParallel(ArrayList<LinkedDimGroup> groups, int sType, boolean countSpanning)
 	{
 		int size = sType == LayoutUtil.MAX ? LayoutUtil.INF : 0;
 		for (int i = 0, iSz = groups.size(); i < iSz; i++) {
@@ -2179,7 +2187,7 @@ public final class Grid
 		return new FlowSizeSpec(sizes, resConstsInclGaps);
 	}
 
-	private static final int[] mergeSizes(int[] oldValues, int[] newValues)
+	private static int[] mergeSizes(int[] oldValues, int[] newValues)
 	{
 		if (oldValues == null)
 			return newValues;
@@ -2194,7 +2202,7 @@ public final class Grid
 		return ret;
 	}
 
-	private static final int mergeSizes(int oldValue, int newValue, boolean toMax)
+	private static int mergeSizes(int oldValue, int newValue, boolean toMax)
 	{
 		if (oldValue == LayoutUtil.NOT_SET || oldValue == newValue)
 			return newValue;
@@ -2205,12 +2213,12 @@ public final class Grid
 		return toMax != oldValue > newValue ? newValue : oldValue;
 	}
 
-	private static final int constrainSize(int s)
+	private static int constrainSize(int s)
 	{
 		return s > 0 ? (s < LayoutUtil.INF ? s : LayoutUtil.INF) : 0;
 	}
 
-	private static final void correctMinMax(int s[])
+	private static void correctMinMax(int s[])
 	{
 		if (s[LayoutUtil.MIN] > s[LayoutUtil.MAX])
 			s[LayoutUtil.MIN] = s[LayoutUtil.MAX];  // Since MAX is almost always explicitly set use that
@@ -2249,7 +2257,7 @@ public final class Grid
 		 * </ul>
 		 * @return The new size.
 		 */
-		private final int expandSizes(DimConstraint[] specs, Float[] defGrow, int targetSize, int fromIx, int len, int sizeType, int eagerness)
+		private int expandSizes(DimConstraint[] specs, Float[] defGrow, int targetSize, int fromIx, int len, int sizeType, int eagerness)
 		{
 			ResizeConstraint[] resConstr = new ResizeConstraint[len];
 			int[][] sizesToExpand = new int[len][];
