@@ -407,7 +407,9 @@ public class IDEUtil
 			if (asAPI) {
 				sb.append(isHor ? ".gapX(\"" : ".gapY(\"").append(getBS(gapBef)).append("\", \"").append(getBS(gapAft)).append("\")");
 			} else {
-				sb.append(isHor ? ",gapx " : ",gapy ").append(getBS(gapBef)).append(' ').append(getBS(gapAft));
+				sb.append(isHor ? ",gapx " : ",gapy ").append(getBS(gapBef));
+				if (gapAft != null)
+					sb.append(' ').append(getBS(gapAft));
 			}
 		}
 	}
@@ -438,9 +440,9 @@ public class IDEUtil
 				}
 			} else {
 				if (asAPI) {
-					sb.append(isHor ? ".width(\"" : ".height(\":").append(getBS(size)).append("\")");
+					sb.append(isHor ? ".width(\"" : ".height(\"").append(getBS(size)).append("\")");
 				} else {
-					sb.append(isHor ? ",width " : ",height :").append(getBS(size));
+					sb.append(isHor ? ",width " : ",height ").append(getBS(size));
 				}
 			}
 		}
