@@ -44,12 +44,12 @@ import java.util.WeakHashMap;
 public final class LayoutUtil
 {
 	/** A substitute value for aa really large value. Integer.MAX_VALUE is not used since that means a lot of defensive code
-	 * for potential overflow must exist in many places. This value is large enough for being unresonable yet it is hard to
+	 * for potential overflow must exist in many places. This value is large enough for being unreasonable yet it is hard to
 	 * overflow.
 	 */
-	static final int INF = (Integer.MAX_VALUE >> 10) - 100; // To reduce likelyhood of overflow errors when calculating.
+	static final int INF = (Integer.MAX_VALUE >> 10) - 100; // To reduce likelihood of overflow errors when calculating.
 
-	/** Tag int for a value that in considered "not set". Used as "null" element in int arays.
+	/** Tag int for a value that in considered "not set". Used as "null" element in int arrays.
 	 */
 	static final int NOT_SET = Integer.MIN_VALUE + 12346;   // Magic value...
 
@@ -58,8 +58,8 @@ public final class LayoutUtil
 	public static final int PREF = 1;
 	public static final int MAX = 2;
 
-	private static WeakHashMap<Object, String> CR_MAP = null;
-	private static WeakHashMap<Object, Boolean> DT_MAP = null;      // The Containers that have design time. Value not used.
+	private static volatile WeakHashMap<Object, String> CR_MAP = null;
+	private static volatile WeakHashMap<Object, Boolean> DT_MAP = null;      // The Containers that have design time. Value not used.
 	private static int eSz = 0;
 	private static int globalDebugMillis = 0;
 
@@ -72,7 +72,7 @@ public final class LayoutUtil
 	 */
 	public static String getVersion()
 	{
-		return "3.7.2";
+		return "3.7.4";
 	}
 
 	/** If global debug should be on or off. If &gt; 0 then debug is turned on for all MigLayout
@@ -114,7 +114,7 @@ public final class LayoutUtil
 		if (DT_MAP == null)
 			DT_MAP = new WeakHashMap<Object, Boolean>();
 
-		DT_MAP.put((cw != null ? cw.getComponent() : null), new Boolean(b));
+		DT_MAP.put((cw != null ? cw.getComponent() : null), Boolean.valueOf(b));
 	}
 
 	/** Returns if design time is turned on for a Container in {@link ContainerWrapper}.
@@ -171,21 +171,21 @@ public final class LayoutUtil
 		}
 	}
 
-	/** Sets/add the persistence delagates to be used for a class.
+	/** Sets/add the persistence delegates to be used for a class.
 	 * @param c The class to set the registered deligate for.
-	 * @param del The new deligate or <code>null</code> to erase to old one.
+	 * @param del The new delegate or <code>null</code> to erase to old one.
 	 */
 	static synchronized void setDelegate(Class c, PersistenceDelegate del)
 	{
 		try {
 			Introspector.getBeanInfo(c, Introspector.IGNORE_ALL_BEANINFO).getBeanDescriptor().setValue("persistenceDelegate", del);
-		} catch (Exception e1) {
+		} catch (Exception ignored) {
 		}
 	}
 
 	/** Returns strings set with {@link #putCCString(Object, String)} or <code>null</code> if nothing is associated or
 	 * {@link LayoutUtil#isDesignTime(ContainerWrapper)} returns <code>false</code>.
-	 * @param con The constraitn object.
+	 * @param con The constrain object.
 	 * @return The creation string or <code>null</code> if nothing is registered with the <code>con</code> object.
 	 */
 	static String getCCString(Object con)
@@ -199,12 +199,12 @@ public final class LayoutUtil
 	}
 
 	/** Takes a number on min/preferred/max sizes and resize constraints and returns the calculated sizes which sum should add up to <code>bounds</code>. Whether the sum
-	 * will actually equal <code>bounds</code> is dependent om the pref/max sizes and resise constraints.
+	 * will actually equal <code>bounds</code> is dependent om the pref/max sizes and resize constraints.
 	 * @param sizes [ix],[MIN][PREF][MAX]. Grid.CompWrap.NOT_SET will be treated as N/A or 0. A "[MIN][PREF][MAX]" array with null elements will be interpreted as very flexible (no bounds)
 	 * but if the array itself is null it will not get any size.
 	 * @param resConstr Elements can be <code>null</code> and the whole array can be <code>null</code>. <code>null</code> means that the size will not be flexible at all.
 	 * Can have length less than <code>sizes</code> in which case the last element should be used for the elements missing.
-	 * @param defPushWeights If there is no grow weight for a resConstr the correspinding value of this array is used.
+	 * @param defPushWeights If there is no grow weight for a resConstr the corresponding value of this array is used.
 	 * These forced resConstr will be grown last though and only if needed to fill to the bounds.
 	 * @param startSizeType The initial size to use. E.g. {@link net.miginfocom.layout.LayoutUtil#MIN}.
 	 * @param bounds To use for relative sizes.
@@ -237,7 +237,7 @@ public final class LayoutUtil
 			for (int i = 0; i < sizes.length; i++) {
 				ResizeConstraint resC = (ResizeConstraint) getIndexSafe(resConstr, i);
 				if (resC != null)
-					prioList.add(new Integer(isGrow ? resC.growPrio : resC.shrinkPrio));
+					prioList.add(Integer.valueOf(isGrow ? resC.growPrio : resC.shrinkPrio));
 			}
 			Integer[] prioIntegers = prioList.toArray(new Integer[prioList.size()]);
 
@@ -315,19 +315,19 @@ public final class LayoutUtil
 	 * @param sz The size to check
 	 * @param lower The lower boundary (or <code>null</code> fo no boundary).
 	 * @param upper The upper boundary (or <code>null</code> fo no boundary).
-	 * @return The broken boundary or <code>null</code> if no boundary was broken.
+	 * @return The broken boundary.
 	 */
 	private static int getBrokenBoundary(float sz, int lower, int upper)
 	{
 		if (lower != NOT_SET) {
 			if (sz < lower)
-				return new Integer(lower);
+				return lower;
 		} else if (sz < 0f) {
-			return new Integer(0);
+			return 0;
 		}
 
 		if (upper != NOT_SET && sz > upper)
-			return new Integer(upper);
+			return upper;
 
 		return NOT_SET;
 	}
@@ -372,7 +372,7 @@ public final class LayoutUtil
 	 * @param container The parent that may be used to get the left-to-right if ffc does not specify this.
 	 * @return If left-to-right orientation is currently used.
 	 */
-	public final static boolean isLeftToRight(LC lc, ContainerWrapper container)
+	public static boolean isLeftToRight(LC lc, ContainerWrapper container)
 	{
 		if (lc != null && lc.getLeftToRight() != null)
 			return lc.getLeftToRight().booleanValue();
@@ -405,7 +405,7 @@ public final class LayoutUtil
 	 * @param o2 The second object. May be <code>null</code>.
 	 * @return Returns <code>true</code> if <code>o1</code> and <code>o2</code> are equal (using .equals()) or both are <code>null</code>.
 	 */
-	static final boolean equals(Object o1, Object o2)
+	static boolean equals(Object o1, Object o2)
 	{
 		return o1 == o2 || (o1 != null && o2 != null && o1.equals(o2));
 	}
@@ -440,7 +440,7 @@ public final class LayoutUtil
 	 * @param getDefault If <code>true</code> the default insets will get retrieved if <code>lc</code> has none set.
 	 * @return The inset for the side. Never <code>null</code>.
 	 */
-	static final UnitValue getInsets(LC lc, int side, boolean getDefault)
+	static UnitValue getInsets(LC lc, int side, boolean getDefault)
 	{
 		UnitValue[] i = lc.getInsets();
 		return (i != null && i[side] != null) ? i[side] : (getDefault ? PlatformDefaults.getPanelInsets(side) : UnitValue.ZERO);
@@ -507,7 +507,7 @@ public final class LayoutUtil
 		try {
 			oldCL = cThread.getContextClassLoader();
 			cThread.setContextClassLoader(LayoutUtil.class.getClassLoader());
-		} catch(SecurityException e) {
+		} catch(SecurityException ignored) {
 		}
 
 		Object o = null;
@@ -520,7 +520,7 @@ public final class LayoutUtil
 
 			o = new XMLDecoder(new ByteArrayInputStream(readBuf, 0, length)).readObject();
 
-		} catch(EOFException e) {
+		} catch(EOFException ignored) {
 		}
 
 		if (oldCL != null)
@@ -532,7 +532,7 @@ public final class LayoutUtil
 	private static final IdentityHashMap<Object, Object> SER_MAP = new IdentityHashMap<Object, Object>(2);
 
 	/** Sets the serialized object and associates it with <code>caller</code>.
-	 * @param caller The objec created <code>o</code>
+	 * @param caller The object created <code>o</code>
 	 * @param o The just serialized object.
 	 */
 	public static void setSerializedObject(Object caller, Object o)
