@@ -184,25 +184,25 @@ public final class UnitValue implements Serializable
 	private static final int IDENTITY = -1;
 
 	static {
-		UNIT_MAP.put("px", new Integer(PIXEL));
-		UNIT_MAP.put("lpx", new Integer(LPX));
-		UNIT_MAP.put("lpy", new Integer(LPY));
-		UNIT_MAP.put("%", new Integer(PERCENT));
-		UNIT_MAP.put("cm", new Integer(CM));
-		UNIT_MAP.put("in", new Integer(INCH));
-		UNIT_MAP.put("spx", new Integer(SPX));
-		UNIT_MAP.put("spy", new Integer(SPY));
-		UNIT_MAP.put("al", new Integer(ALIGN));
-		UNIT_MAP.put("mm", new Integer(MM));
-		UNIT_MAP.put("pt", new Integer(PT));
-		UNIT_MAP.put("min", new Integer(MIN_SIZE));
-		UNIT_MAP.put("minimum", new Integer(MIN_SIZE));
-		UNIT_MAP.put("p", new Integer(PREF_SIZE));
-		UNIT_MAP.put("pref", new Integer(PREF_SIZE));
-		UNIT_MAP.put("max", new Integer(MAX_SIZE));
-		UNIT_MAP.put("maximum", new Integer(MAX_SIZE));
-		UNIT_MAP.put("button", new Integer(BUTTON));
-		UNIT_MAP.put("label", new Integer(LABEL_ALIGN));
+		UNIT_MAP.put("px", Integer.valueOf(PIXEL));
+		UNIT_MAP.put("lpx", Integer.valueOf(LPX));
+		UNIT_MAP.put("lpy", Integer.valueOf(LPY));
+		UNIT_MAP.put("%", Integer.valueOf(PERCENT));
+		UNIT_MAP.put("cm", Integer.valueOf(CM));
+		UNIT_MAP.put("in", Integer.valueOf(INCH));
+		UNIT_MAP.put("spx", Integer.valueOf(SPX));
+		UNIT_MAP.put("spy", Integer.valueOf(SPY));
+		UNIT_MAP.put("al", Integer.valueOf(ALIGN));
+		UNIT_MAP.put("mm", Integer.valueOf(MM));
+		UNIT_MAP.put("pt", Integer.valueOf(PT));
+		UNIT_MAP.put("min", Integer.valueOf(MIN_SIZE));
+		UNIT_MAP.put("minimum", Integer.valueOf(MIN_SIZE));
+		UNIT_MAP.put("p", Integer.valueOf(PREF_SIZE));
+		UNIT_MAP.put("pref", Integer.valueOf(PREF_SIZE));
+		UNIT_MAP.put("max", Integer.valueOf(MAX_SIZE));
+		UNIT_MAP.put("maximum", Integer.valueOf(MAX_SIZE));
+		UNIT_MAP.put("button", Integer.valueOf(BUTTON));
+		UNIT_MAP.put("label", Integer.valueOf(LABEL_ALIGN));
 	}
 
 	static final UnitValue ZERO = new UnitValue(0, null, PIXEL, true, STATIC, null, null, "0px");
@@ -495,7 +495,7 @@ public final class UnitValue implements Serializable
 
 	public final UnitValue[] getSubUnits()
 	{
-		return subUnits;
+		return subUnits != null ? subUnits.clone() : null;
 	}
 
 	public final int getUnit()
@@ -548,7 +548,7 @@ public final class UnitValue implements Serializable
 	 * can be overridden. It is however not possible to override the built in ones (e.g. "mm", "pixel" or "lp").
 	 * @param conv The converter. Not <code>null</code>.
 	 */
-	public final synchronized static void addGlobalUnitConverter(UnitConverter conv)
+	public synchronized static void addGlobalUnitConverter(UnitConverter conv)
 	{
 		if (conv == null)
 			throw new NullPointerException();
@@ -559,7 +559,7 @@ public final class UnitValue implements Serializable
 	 * @param unit The converter.
 	 * @return If there was a converter found and thus removed.
 	 */
-	public final synchronized static boolean removeGlobalUnitConverter(String unit)
+	public synchronized static boolean removeGlobalUnitConverter(UnitConverter unit)
 	{
 		return CONVERTERS.remove(unit);
 	}
@@ -567,7 +567,7 @@ public final class UnitValue implements Serializable
 	/** Returns the global converters currently registered. The platform converter will not be in this list.
 	 * @return The converters. Never <code>null</code>.
 	 */
-	public final synchronized static UnitConverter[] getGlobalUnitConverters()
+	public synchronized static UnitConverter[] getGlobalUnitConverters()
 	{
 		return CONVERTERS.toArray(new UnitConverter[CONVERTERS.size()]);
 	}
@@ -578,7 +578,7 @@ public final class UnitValue implements Serializable
 	 * @see #LPX
 	 * @deprecated Use {@link PlatformDefaults#getDefaultHorizontalUnit()} and {@link PlatformDefaults#getDefaultVerticalUnit()} instead.
 	 */
-	public final static int getDefaultUnit()
+	public static int getDefaultUnit()
 	{
 		return PlatformDefaults.getDefaultHorizontalUnit();
 	}
@@ -589,7 +589,7 @@ public final class UnitValue implements Serializable
 	 * @see #LPX
 	 * @deprecated Use {@link PlatformDefaults#setDefaultHorizontalUnit(int)} and {@link PlatformDefaults#setDefaultVerticalUnit(int)} instead.
 	 */
-	public final static void setDefaultUnit(int unit)
+	public static void setDefaultUnit(int unit)
 	{
 		PlatformDefaults.setDefaultHorizontalUnit(unit);
 		PlatformDefaults.setDefaultVerticalUnit(unit);
