@@ -41,10 +41,9 @@ import java.awt.*;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 import java.io.*;
-import java.lang.ref.WeakReference;
 import java.util.*;
 
-/** A very flexbile layout manager.
+/** A very flexible layout manager.
  * <p>
  * Read the documentation that came with this layout manager for information on usage.
  */
@@ -74,6 +73,7 @@ public final class MigLayout implements LayoutManager2, Externalizable
 	private transient int lastHash = -1;
 	private transient Dimension lastInvalidSize = null;
 	private transient boolean lastWasInvalid = false;  // Added in 3.7.1. May have regressions
+	private transient Dimension lastParentSize = null;
 
 	private transient ArrayList<LayoutCallback> callbackList = null;
 
@@ -116,7 +116,7 @@ public final class MigLayout implements LayoutManager2, Externalizable
 	}
 
 	/** Constructor.
-	 * @param layoutConstraints The constraints that concern the whole layout. <code>null</code> will be treated as an empty cosntraint.
+	 * @param layoutConstraints The constraints that concern the whole layout. <code>null</code> will be treated as an empty constraint.
 	 */
 	public MigLayout(LC layoutConstraints)
 	{
@@ -124,7 +124,7 @@ public final class MigLayout implements LayoutManager2, Externalizable
 	}
 
 	/** Constructor.
-	 * @param layoutConstraints The constraints that concern the whole layout. <code>null</code> will be treated as an empty cosntraint.
+	 * @param layoutConstraints The constraints that concern the whole layout. <code>null</code> will be treated as an empty constraint.
 	 * @param colConstraints The constraints for the columns in the grid. <code>null</code> will be treated as an empty constraint.
 	 */
 	public MigLayout(LC layoutConstraints, AC colConstraints)
@@ -133,7 +133,7 @@ public final class MigLayout implements LayoutManager2, Externalizable
 	}
 
 	/** Constructor.
-	 * @param layoutConstraints The constraints that concern the whole layout. <code>null</code> will be treated as an empty cosntraint.
+	 * @param layoutConstraints The constraints that concern the whole layout. <code>null</code> will be treated as an empty constraint.
 	 * @param colConstraints The constraints for the columns in the grid. <code>null</code> will be treated as an empty constraint.
 	 * @param rowConstraints The constraints for the rows in the grid. <code>null</code> will be treated as an empty constraint.
 	 */
@@ -158,7 +158,7 @@ public final class MigLayout implements LayoutManager2, Externalizable
 	 * <p>
 	 * See the class JavaDocs for information on how this string is formatted.
 	 * @param constr The layout constraints as a String representation. <code>null</code> is converted to <code>""</code> for storage.
-	 * @throws RuntimeException if the constaint was not valid.
+	 * @throws RuntimeException if the constraint was not valid.
 	 */
 	public void setLayoutConstraints(Object constr)
 	{
@@ -187,7 +187,7 @@ public final class MigLayout implements LayoutManager2, Externalizable
 	 * <p>
 	 * See the class JavaDocs for information on how this string is formatted.
 	 * @param constr The column layout constraints as a String representation. <code>null</code> is converted to <code>""</code> for storage.
-	 * @throws RuntimeException if the constaint was not valid.
+	 * @throws RuntimeException if the constraint was not valid.
 	 */
 	public void setColumnConstraints(Object constr)
 	{
@@ -218,7 +218,7 @@ public final class MigLayout implements LayoutManager2, Externalizable
 	 * <p>
 	 * See the class JavaDocs for information on how this string is formatted.
 	 * @param constr The row layout constraints as a String representation. <code>null</code> is converted to <code>""</code> for storage.
-	 * @throws RuntimeException if the constaint was not valid.
+	 * @throws RuntimeException if the constraint was not valid.
 	 */
 	public void setRowConstraints(Object constr)
 	{
@@ -269,26 +269,26 @@ public final class MigLayout implements LayoutManager2, Externalizable
 		}
 	}
 
-	/** Sets the component constraint for the component that already must be handleded by this layout manager.
+	/** Sets the component constraint for the component that already must be handled by this layout manager.
 	 * <p>
 	 * See the class JavaDocs for information on how this string is formatted.
 	 * @param constr The component constraints as a String or {@link net.miginfocom.layout.CC}. <code>null</code> is ok.
 	 * @param comp The component to set the constraints for.
-	 * @throws RuntimeException if the constaint was not valid.
-	 * @throws IllegalArgumentException If the component is not handlering the component.
+	 * @throws RuntimeException if the constraint was not valid.
+	 * @throws IllegalArgumentException If the component is not handling the component.
 	 */
 	public void setComponentConstraints(Component comp, Object constr)
 	{
 		setComponentConstraintsImpl(comp, constr, false);
 	}
 
-	/** Sets the component constraint for the component that already must be handleded by this layout manager.
+	/** Sets the component constraint for the component that already must be handled by this layout manager.
 	 * <p>
 	 * See the class JavaDocs for information on how this string is formatted.
 	 * @param constr The component constraints as a String or {@link net.miginfocom.layout.CC}. <code>null</code> is ok.
 	 * @param comp The component to set the constraints for.
 	 * @param noCheck Doe not check if the component is handled if true
-	 * @throws RuntimeException if the constaint was not valid.
+	 * @throws RuntimeException if the constraint was not valid.
 	 * @throws IllegalArgumentException If the component is not handling the component.
 	 */
 	private void setComponentConstraintsImpl(Component comp, Object constr, boolean noCheck)
@@ -354,7 +354,7 @@ public final class MigLayout implements LayoutManager2, Externalizable
 	/** Sets the debugging state for this layout manager instance. If debug is turned on a timer will repaint the last laid out parent
 	 * with debug information on top.
 	 * <p>
-	 * Red fill and dashed darked red outline is used to indicate occupied cells in the grid. Blue dashed outline indicate indicate
+	 * Red fill and dashed red outline is used to indicate occupied cells in the grid. Blue dashed outline indicate indicate
 	 * component bounds set.
 	 * <p>
 	 * Note that debug can also be set on the layout constraints. There it will be persisted. The value set here will not. See the class
@@ -362,7 +362,7 @@ public final class MigLayout implements LayoutManager2, Externalizable
 	 * @param parentW The parent to set debug for.
 	 * @param b <code>true</code> means debug is turned on.
 	 */
-	private synchronized void setDebug(final ComponentWrapper parentW, boolean b)
+	private void setDebug(final ComponentWrapper parentW, boolean b)
 	{
 		if (b && (debugTimer == null || debugTimer.getDelay() != getDebugMillis())) {
 			if (debugTimer != null)
@@ -371,7 +371,7 @@ public final class MigLayout implements LayoutManager2, Externalizable
 			ContainerWrapper pCW = parentW.getParent();
 			final Component parent = pCW != null ? (Component) pCW.getComponent() : null;
 
-			debugTimer = new Timer(getDebugMillis(), new MyDebugRepaintListener(MigLayout.this));
+			debugTimer = new Timer(getDebugMillis(), new MyDebugRepaintListener());
 
 			if (parent != null) {
 				SwingUtilities.invokeLater(new Runnable() {
@@ -415,7 +415,7 @@ public final class MigLayout implements LayoutManager2, Externalizable
 		return globalDebugMillis > 0 ? globalDebugMillis : lc.getDebugMillis();
 	}
 
-	/** Check if something has changed and if so recrete it to the cached objects.
+	/** Check if something has changed and if so recreate it to the cached objects.
 	 * @param parent The parent that is the target for this layout manager.
 	 */
 	private void checkCache(Container parent)
@@ -438,8 +438,16 @@ public final class MigLayout implements LayoutManager2, Externalizable
 				lastWasInvalid = true;
 
 				int hash = 0;
-				for (Iterator<ComponentWrapper> it = ccMap.keySet().iterator(); it.hasNext();)
-					hash += it.next().getLayoutHashCode();
+				boolean resetLastInvalidOnParent = false; // Added in 3.7.3 to resolve a timing regression introduced in 3.7.1
+				for (Iterator<ComponentWrapper> it = ccMap.keySet().iterator(); it.hasNext();) {
+					ComponentWrapper wrapper = it.next();
+					Object component = wrapper.getComponent();
+					if (component instanceof JTextArea || component instanceof JEditorPane)
+						resetLastInvalidOnParent = true;
+					hash += wrapper.getLayoutHashCode();
+				}
+				if (resetLastInvalidOnParent)
+					resetLastInvalidOnParent(parent);
 
 				if (hash != lastHash) {
 					grid = null;
@@ -467,6 +475,20 @@ public final class MigLayout implements LayoutManager2, Externalizable
 		dirty = false;
 	}
 
+	/**
+	 * @since 3.7.3
+	 */
+	private void resetLastInvalidOnParent(Container parent)
+	{
+		while (parent != null) {
+			LayoutManager layoutManager = parent.getLayout();
+			if (layoutManager instanceof MigLayout) {
+				((MigLayout) layoutManager).lastWasInvalid = false;
+			}
+			parent = parent.getParent();
+		}
+	}
+
 	private ContainerWrapper checkParent(Container parent)
 	{
 		if (parent == null)
@@ -570,7 +592,18 @@ public final class MigLayout implements LayoutManager2, Externalizable
 	public Dimension preferredLayoutSize(Container parent)
 	{
 		synchronized(parent.getTreeLock()) {
-			return getSizeImpl(parent, LayoutUtil.PREF);
+           if (lastParentSize == null || !parent.getSize().equals(lastParentSize)) {
+               for (ComponentWrapper wrapper : ccMap.keySet()) {
+                   Component c = (Component) wrapper.getComponent();
+                   if (c instanceof JTextArea || c instanceof JEditorPane || (c instanceof JComponent && Boolean.TRUE.equals(((JComponent)c).getClientProperty("migLayout.dynamicAspectRatio")))) {
+                       layoutContainer(parent);
+                       break;
+                   }
+               }
+           }
+
+           lastParentSize = parent.getSize();
+           return getSizeImpl(parent, LayoutUtil.PREF);
 		}
 	}
 
@@ -650,20 +683,19 @@ public final class MigLayout implements LayoutManager2, Externalizable
 			LayoutUtil.writeAsXML(out, this);
 	}
 
-	private static class MyDebugRepaintListener implements ActionListener
+	private class MyDebugRepaintListener implements ActionListener
 	{
-		private final WeakReference<MigLayout> layoutRef;
-
-		private MyDebugRepaintListener(MigLayout layout)
-		{
-			this.layoutRef = new WeakReference<MigLayout>(layout);
-		}
-
 		public void actionPerformed(ActionEvent e)
 		{
-			MigLayout layout = layoutRef.get();
-			if (layout != null && layout.grid != null)
-				layout.grid.paintDebug();
+			if (grid != null) {
+				Component comp = (Component) grid.getContainer().getComponent();
+				if (comp.isShowing()) {
+					grid.paintDebug();
+					return;
+				}
+			}
+			debugTimer.stop();
+			debugTimer = null;
 		}
 	}
 }
\ No newline at end of file
