@@ -72,8 +72,8 @@ public class SwingComponentWrapper implements ComponentWrapper
 
 		try {
 			Object[] args = new Object[] {
-				new Integer(width < 0 ? c.getWidth() : width),
-				new Integer(height < 0 ? c.getHeight() : height)
+				Integer.valueOf(width < 0 ? c.getWidth() : width),
+				Integer.valueOf(height < 0 ? c.getHeight() : height)
 			};
 
 			return ((Integer) BL_METHOD.invoke(c, args)).intValue();
@@ -279,7 +279,7 @@ public class SwingComponentWrapper implements ComponentWrapper
 					bl = Boolean.FALSE;
 				} else {
 					Dimension d = c.getMinimumSize();
-					bl = new Boolean(getBaseline(d.width, d.height) > -1);
+					bl = Boolean.valueOf(getBaseline(d.width, d.height) > -1);
 				}
 			} catch (Throwable ex) {
 				bl = Boolean.FALSE;
@@ -309,6 +309,7 @@ public class SwingComponentWrapper implements ComponentWrapper
 			if (UIManager.getLookAndFeel().getClass().getName().endsWith("WindowsLookAndFeel"))
 				return new int[] {-1, 0, 2, 2};
 		}
+
 		return null;
 	}
 
@@ -379,7 +380,7 @@ public class SwingComponentWrapper implements ComponentWrapper
 //		return id != null ? id.hashCode() : 1;
 	}
 
-	private final int checkType(boolean disregardScrollPane)
+	private int checkType(boolean disregardScrollPane)
 	{
 		Component c = this.c;
 
@@ -447,9 +448,8 @@ public class SwingComponentWrapper implements ComponentWrapper
 	static {
 		try {
 			BL_METHOD = Component.class.getDeclaredMethod("getBaseline", new Class[] {int.class, int.class});
-			BL_RES_METHOD = Component.class.getDeclaredMethod("getBaselineResizeBehavior"); // 3.7.2: Removed Class<?> null since that made the method inaccessible. 
+			BL_RES_METHOD = Component.class.getDeclaredMethod("getBaselineResizeBehavior"); // 3.7.2: Removed Class<?> null since that made the method inaccessible.
 		} catch (Throwable e) { // No such method or security exception
-			e.printStackTrace();
 		}
 	}
 
