@@ -32,7 +32,6 @@ package net.miginfocom.swt;
  * @author Mikael Grev, MiG InfoCom AB
  *         Date: 2006-sep-08
  */
-
 import net.miginfocom.layout.*;
 import org.eclipse.swt.graphics.Point;
 import org.eclipse.swt.graphics.Rectangle;
@@ -51,6 +50,12 @@ import java.util.*;
  */
 public final class MigLayout extends Layout implements Externalizable
 {
+	static {
+		// Mac Swing defaults to 96 DPI from Java6 though SWT is still on 72.
+		if (PlatformDefaults.getPlatform() == PlatformDefaults.MAC_OSX)
+			PlatformDefaults.setDefaultDPI(72);
+	}
+
 	// ******** Instance part ********
 
 	/** The component to string constraints mappings.
@@ -369,7 +374,7 @@ public final class MigLayout extends Layout implements Externalizable
 	/** Check if something has changed and if so recrete it to the cached objects.
 	 * @param parent The parent that is the target for this layout manager.
 	 */
-	private final void checkCache(Composite parent)
+	private void checkCache(Composite parent)
 	{
 		if (parent == null)
 			return;
@@ -425,7 +430,7 @@ public final class MigLayout extends Layout implements Externalizable
 		return changed;
 	}
 
-	private final ContainerWrapper checkParent(Composite parent)
+	private ContainerWrapper checkParent(Composite parent)
 	{
 		if (parent == null)
 			return null;
@@ -513,7 +518,7 @@ public final class MigLayout extends Layout implements Externalizable
 		{
 			final MigLayout layout = layoutRef.get();
 			if (layout != null && layout.grid != null) {
-				Display.getDefault ().asyncExec(new Runnable () {
+				Display.getDefault().asyncExec(new Runnable () {
 					public void run () {
 						if (layout.grid != null)
 							layout.grid.paintDebug();
